@@ -1,18 +1,18 @@
 ;(function(){
   var map = {
-  "commitId": "7413c657b2c440f3a874d202828910f0d90fe72e",
-  "branchName": "release-client-6.0.x",
-  "buildTime": "2024-05-16 13:24:50 GMT",
-  "buildVersion": "1.0.209",
+  "commitId": "b5d99c00a449f7d875006e0b254cc216f2d14ed9",
+  "branchName": "release-client-6.1.x",
+  "buildTime": "2024-08-16 03:23:01 GMT",
+  "buildVersion": "1.0.1204",
   "css": [
-    "@zoom/client-scheduler/static/css/chunk-vendors.5d85ef2c.css",
-    "@zoom/client-scheduler/static/css/index.ae1792a8.css"
+    "@zoom/client-calendar-desktop/static/css/chunk-vendors.49e8f34d.css",
+    "@zoom/client-calendar-desktop/static/css/app.8024bba5.css"
   ],
   "js": [
-    "@zoom/client-scheduler/chunk-vendors.700bb9cd49d4ede7ee4e.js",
-    "@zoom/client-scheduler/index.700bb9cd49d4ede7ee4e.js"
+    "@zoom/client-calendar-desktop/static/js/chunk-vendors.775d7f30.js",
+    "@zoom/client-calendar-desktop/static/js/app.6a9bf114.js"
   ],
-  "key": "clientSchedulerResource"
+  "key": "@zoom/client-calendar-desktop"
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
   map.css && map.css.forEach(function (cssItem) {
